Use a folio throughout this function.  migrate_page() will be converted
later.

Signed-off-by: Matthew Wilcox (Oracle) <wi...@infradead.org>
Acked-by: Anna Schumaker <anna.schuma...@netapp.com>
Reviewed-by: Christoph Hellwig <h...@lst.de>
---
 fs/nfs/file.c     |  4 +---
 fs/nfs/internal.h |  6 ++++--
 fs/nfs/write.c    | 16 ++++++++--------
 3 files changed, 13 insertions(+), 13 deletions(-)

diff --git a/fs/nfs/file.c b/fs/nfs/file.c
index 2d72b1b7ed74..549baed76351 100644
--- a/fs/nfs/file.c
+++ b/fs/nfs/file.c
@@ -533,9 +533,7 @@ const struct address_space_operations nfs_file_aops = {
        .write_end = nfs_write_end,
        .invalidate_folio = nfs_invalidate_folio,
        .release_folio = nfs_release_folio,
-#ifdef CONFIG_MIGRATION
-       .migratepage = nfs_migrate_page,
-#endif
+       .migrate_folio = nfs_migrate_folio,
        .launder_folio = nfs_launder_folio,
        .is_dirty_writeback = nfs_check_dirty_writeback,
        .error_remove_page = generic_error_remove_page,
diff --git a/fs/nfs/internal.h b/fs/nfs/internal.h
index 8f8cd6e2d4db..437ebe544aaf 100644
--- a/fs/nfs/internal.h
+++ b/fs/nfs/internal.h
@@ -578,8 +578,10 @@ void nfs_clear_pnfs_ds_commit_verifiers(struct 
pnfs_ds_commit_info *cinfo)
 #endif
 
 #ifdef CONFIG_MIGRATION
-extern int nfs_migrate_page(struct address_space *,
-               struct page *, struct page *, enum migrate_mode);
+int nfs_migrate_folio(struct address_space *, struct folio *dst,
+               struct folio *src, enum migrate_mode);
+#else
+#define nfs_migrate_folio NULL
 #endif
 
 static inline int
diff --git a/fs/nfs/write.c b/fs/nfs/write.c
index 1c706465d090..649b9e633459 100644
--- a/fs/nfs/write.c
+++ b/fs/nfs/write.c
@@ -2119,27 +2119,27 @@ int nfs_wb_page(struct inode *inode, struct page *page)
 }
 
 #ifdef CONFIG_MIGRATION
-int nfs_migrate_page(struct address_space *mapping, struct page *newpage,
-               struct page *page, enum migrate_mode mode)
+int nfs_migrate_folio(struct address_space *mapping, struct folio *dst,
+               struct folio *src, enum migrate_mode mode)
 {
        /*
         * If PagePrivate is set, then the page is currently associated with
         * an in-progress read or write request. Don't try to migrate it.
         *
         * FIXME: we could do this in principle, but we'll need a way to ensure
         *        that we can safely release the inode reference while holding
         *        the page lock.
         */
-       if (PagePrivate(page))
+       if (folio_test_private(src))
                return -EBUSY;
 
-       if (PageFsCache(page)) {
+       if (folio_test_fscache(src)) {
                if (mode == MIGRATE_ASYNC)
                        return -EBUSY;
-               wait_on_page_fscache(page);
+               folio_wait_fscache(src);
        }
 
-       return migrate_page(mapping, newpage, page, mode);
+       return migrate_page(mapping, &dst->page, &src->page, mode);
 }
 #endif
 
@@ -2119,27 +2119,27 @@ int nfs_wb_page(struct inode *inode, struct page *page)
 {
        /*
-        * If PagePrivate is set, then the page is currently associated with
+        * If the private flag is set, the folio is currently associated with
         * an in-progress read or write request. Don't try to migrate it.
         *
@@ -2119,27 +2119,27 @@ int nfs_wb_page(struct inode *inode, struct page *page)
         * FIXME: we could do this in principle, but we'll need a way to ensure
         *        that we can safely release the inode reference while holding
-        *        the page lock.
+        *        the folio lock.
         */
-- 
2.35.1

Reply via email to